| Parent | ID | ISO Code |
|---|---|---|
| **africa** | | |
| | algeria | DZ |
| | angola | AO |
| | benin | BJ |
| | botswana | BW |
| | burkina-faso | BF |
| | burundi | BI |
| | cameroon | CM |
| | canary-islands |  |
| | cape-verde | CV |
| | central-african-republic | CF |
| | chad | TD |
| | comores |  |
| | congo-brazzaville | CG |
| | congo-democratic-republic | CD |
| | djibouti | DJ |
| | egypt | EG |
| | equatorial-guinea | GQ |
| | eritrea | ER |
| | ethiopia | ET |
| | gabon | GA |
| | ghana | GH |
| | guinea | GN |
| | guinea-bissau | GW |
| | ivory-coast | CI |
| | kenya | KE |
| | lesotho | LS |
| | liberia | LR |
| | libya | LY |
| | madagascar | MG |
| | malawi | MW |
| | mali | ML |
| | mauritania | MR |
| | mauritius | MU |
| | morocco | MA |
| | mozambique | MZ |
| | namibia | NA |
| | niger | NE |
| | nigeria | NG |
| | rwanda | RW |
| | saint-helena-ascension-and-tristan-da-cunha | SH |
| | sao-tome-and-principe | ST |
| | senegal-and-gambia | SN-GM |
| | seychelles | SC |
| | sierra-leone | SL |
| | somalia | SO |
| | south-africa | ZA |
| | south-africa-and-lesotho |  |
| | south-sudan | SS |
| | sudan | SD |
| | swaziland | SZ |
| | tanzania | TZ |
| | togo | TG |
| | tunisia | TN |
| | uganda | UG |
| | zambia | ZM |
| | zimbabwe | ZW |
| **asia** | | |
| | afghanistan | AF |
| | armenia | AM |
| | azerbaijan | AZ |
| | bangladesh | BD |
| | bhutan | BT |
| | cambodia | KH |
| | china | CN |
| | east-timor | TL |
| | gcc-states | QA-AE-OM-BH-KW |
| | india | IN |
| | indonesia | ID |
| | iran | IR |
| | iraq | IQ |
| | israel-and-palestine | PS-IL |
| | japan | JP |
| | jordan | JO |
| | kazakhstan | KZ |
| | kyrgyzstan | KG |
| | laos | LA |
| | lebanon | LB |
| | malaysia-singapore-brunei | MY |
| | maldives | MV |
| | mongolia | MN |
| | myanmar | MM |
| | nepal | NP |
| | north-korea | KP |
| | pakistan | PK |
| | philippines | PH |
| | south-korea | KR |
| | sri-lanka | LK |
| | syria | SY |
| | taiwan | TW |
| | tajikistan | TJ |
| | thailand | TH |
| | turkmenistan | TM |
| | uzbekistan | UZ |
| | vietnam | VN |
| | yemen | YE |
| **australia-oceania** | | |
| | american-oceania | VU |
| | australia | AU |
| | cook-islands | CK |
| | fiji | FJ |
| | ile-de-clipperton | VU |
| | kiribati | KI |
| | marshall-islands | MH |
| | micronesia | FM |
| | nauru | NR |
| | new-caledonia | NC |
| | new-zealand | NZ |
| | niue | NU |
| | palau | PW |
| | papua-new-guinea | PG |
| | pitcairn-islands | MH |
| | polynesie-francaise | VU |
| | samoa | WS |
| | solomon-islands | SB |
| | tokelau | VU |
| | tonga | TO |
| | tuvalu | TV |
| | vanuatu | VU |
| | wallis-et-futuna | VU |
| **central-america** | | |
| | bahamas |  |
| | belize | BZ |
| | costa-rica | CR |
| | cuba |  |
| | el-salvador | SV |
| | guatemala | GT |
| | haiti-and-domrep |  |
| | honduras | HN |
| | jamaica |  |
| | nicaragua | NI |
| | panama |  |
| **europe** | | |
| | albania | AL |
| | alps |  |
| | andorra | AD |
| | austria | AT |
| | azores |  |
| | belarus | BY |
| | belgium | BE |
| | bosnia-herzegovina | BA |
| | britain-and-ireland |  |
| | bulgaria | BG |
| | croatia | HR |
| | cyprus | CY |
| | czech-republic | CZ |
| | dach |  |
| | denmark | DK |
| | estonia | EE |
| | faroe-islands | FO |
| | finland | FI |
| | france | FR |
| | georgia | GE |
| | germany | DE |
| | great-britain | GB |
| | greece | GR |
| | guernsey-jersey |  |
| | hungary | HU |
| | iceland | IS |
| | ireland-and-northern-ireland | IE |
| | isle-of-man |  |
| | italy | IT |
| | kosovo | RS-KM |
| | latvia | LV |
| | liechtenstein | LI |
| | lithuania | LT |
| | luxembourg | LU |
| | macedonia | MK |
| | malta | MT |
| | moldova | MD |
| | monaco | MC |
| | montenegro | ME |
| | netherlands | NL |
| | norway | NO |
| | poland | PL |
| | portugal | PT |
| | romania | RO |
| | serbia | RS |
| | slovakia | SK |
| | slovenia | SI |
| | spain | ES |
| | sweden | SE |
| | switzerland | CH |
| | turkey | TR |
| | ukraine | UA |
| **north-america** | | |
| | canada | CA |
| | greenland | GL |
| | mexico | MX |
| | us | US |
| | us-midwest |  |
| | us-northeast |  |
| | us-pacific |  |
| | us-south |  |
| | us-west |  |
| | us/alabama | US-AL |
| | us/alaska | US-AK |
| | us/arizona | US-AZ |
| | us/arkansas | US-AR |
| | us/california | US-CA |
| | us/colorado | US-CO |
| | us/connecticut | US-CT |
| | us/delaware | US-DE |
| | us/district-of-columbia | US-DC |
| | us/florida | US-FL |
| | us/georgia | US-GA |
| | us/hawaii | US-HI |
| | us/idaho | US-ID |
| | us/illinois | US-IL |
| | us/indiana | US-IN |
| | us/iowa | US-IA |
| | us/kansas | US-KS |
| | us/kentucky | US-KY |
| | us/louisiana | US-LA |
| | us/maine | US-ME |
| | us/maryland | US-MD |
| | us/massachusetts | US-MA |
| | us/michigan | US-MI |
| | us/minnesota | US-MN |
| | us/mississippi | US-MS |
| | us/missouri | US-MO |
| | us/montana | US-MT |
| | us/nebraska | US-NE |
| | us/nevada | US-NV |
| | us/new-hampshire | US-NH |
| | us/new-jersey | US-NJ |
| | us/new-mexico | US-NM |
| | us/new-york | US-NY |
| | us/north-carolina | US-NC |
| | us/north-dakota | US-ND |
| | us/ohio | US-OH |
| | us/oklahoma | US-OK |
| | us/oregon | US-OR |
| | us/pennsylvania | US-PA |
| | us/puerto-rico | PR |
| | us/rhode-island | US-RI |
| | us/south-carolina | US-SC |
| | us/south-dakota | US-SD |
| | us/tennessee | US-TN |
| | us/texas | US-TX |
| | us/us-virgin-islands | VI |
| | us/utah | US-UT |
| | us/vermont | US-VT |
| | us/virginia | US-VA |
| | us/washington | US-WA |
| | us/west-virginia | US-WV |
| | us/wisconsin | US-WI |
| | us/wyoming | US-WY |
| **russia** | | |
| | central-fed-district |  |
| | crimean-fed-district | UA-43 |
| | far-eastern-fed-district |  |
| | kaliningrad |  |
| | north-caucasus-fed-district |  |
| | northwestern-fed-district |  |
| | siberian-fed-district |  |
| | south-fed-district |  |
| | ural-fed-district |  |
| | volga-fed-district |  |
| **south-america** | | |
| | argentina | AR |
| | bolivia | BO |
| | brazil | BR |
| | chile | CL |
| | colombia | CO |
| | ecuador | EC |
| | guyana | GY |
| | paraguay | PY |
| | peru | PE |
| | suriname | SR |
| | uruguay | UY |
| | venezuela | VE |
| **baden-wuerttemberg** | | |
| | freiburg-regbez |  |
| | karlsruhe-regbez |  |
| | stuttgart-regbez |  |
| | tuebingen-regbez |  |
| **bayern** | | |
| | mittelfranken |  |
| | niederbayern |  |
| | oberbayern |  |
| | oberfranken |  |
| | oberpfalz |  |
| | schwaben |  |
| | unterfranken |  |
| **brazil** | | |
| | centro-oeste |  |
| | nordeste |  |
| | norte |  |
| | sudeste |  |
| | sul |  |
| **canada** | | |
| | alberta | CA-AB |
| | british-columbia | CA-BC |
| | manitoba | CA-MB |
| | new-brunswick | CA-NB |
| | newfoundland-and-labrador | CA-NL |
| | northwest-territories | CA-NT |
| | nova-scotia | CA-NS |
| | nunavut | CA-NU |
| | ontario | CA-ON |
| | prince-edward-island | CA-PE |
| | quebec | CA-QC |
| | saskatchewan | CA-SK |
| | yukon | CA-YT |
| **england** | | |
| | bedfordshire |  |
| | berkshire |  |
| | bristol |  |
| | buckinghamshire |  |
| | cambridgeshire |  |
| | cheshire |  |
| | cornwall |  |
| | cumbria |  |
| | derbyshire |  |
| | devon |  |
| | dorset |  |
| | durham |  |
| | east-sussex |  |
| | east-yorkshire-with-hull |  |
| | essex |  |
| | gloucestershire |  |
| | greater-london |  |
| | greater-manchester |  |
| | hampshire |  |
| | herefordshire |  |
| | hertfordshire |  |
| | isle-of-wight |  |
| | kent |  |
| | lancashire |  |
| | leicestershire |  |
| | lincolnshire |  |
| | merseyside |  |
| | norfolk |  |
| | north-yorkshire |  |
| | northamptonshire |  |
| | northumberland |  |
| | nottinghamshire |  |
| | oxfordshire |  |
| | rutland |  |
| | shropshire |  |
| | somerset |  |
| | south-yorkshire |  |
| | staffordshire |  |
| | suffolk |  |
| | surrey |  |
| | tyne-and-wear |  |
| | warwickshire |  |
| | west-midlands |  |
| | west-sussex |  |
| | west-yorkshire |  |
| | wiltshire |  |
| | worcestershire |  |
| **france** | | |
| | alsace |  |
| | aquitaine |  |
| | auvergne |  |
| | basse-normandie |  |
| | bourgogne |  |
| | bretagne |  |
| | centre |  |
| | champagne-ardenne |  |
| | corse |  |
| | franche-comte |  |
| | guadeloupe |  |
| | guyane | GF |
| | haute-normandie |  |
| | ile-de-france |  |
| | languedoc-roussillon |  |
| | limousin |  |
| | lorraine |  |
| | martinique |  |
| | mayotte |  |
| | midi-pyrenees |  |
| | nord-pas-de-calais |  |
| | pays-de-la-loire |  |
| | picardie |  |
| | poitou-charentes |  |
| | provence-alpes-cote-d-azur |  |
| | reunion |  |
| | rhone-alpes |  |
| **germany** | | |
| | baden-wuerttemberg |  |
| | bayern |  |
| | berlin |  |
| | brandenburg |  |
| | bremen |  |
| | hamburg |  |
| | hessen |  |
| | mecklenburg-vorpommern |  |
| | niedersachsen |  |
| | nordrhein-westfalen |  |
| | rheinland-pfalz |  |
| | saarland |  |
| | sachsen |  |
| | sachsen-anhalt |  |
| | schleswig-holstein |  |
| | thueringen |  |
| **great-britain** | | |
| | england |  |
| | scotland |  |
| | wales |  |
| **greater-london** | | |
| | enfield |  |
| **india** | | |
| | central-zone |  |
| | eastern-zone |  |
| | north-eastern-zone |  |
| | northern-zone |  |
| | southern-zone |  |
| | western-zone |  |
| **indonesia** | | |
| | java |  |
| | kalimantan |  |
| | maluku |  |
| | nusa-tenggara |  |
| | papua |  |
| | sulawesi |  |
| | sumatra |  |
| **italy** | | |
| | centro |  |
| | isole |  |
| | nord-est |  |
| | nord-ovest |  |
| | sud |  |
| **japan** | | |
| | chubu |  |
| | chugoku |  |
| | hokkaido |  |
| | kansai |  |
| | kanto |  |
| | kyushu |  |
| | shikoku |  |
| | tohoku |  |
| **netherlands** | | |
| | drenthe |  |
| | flevoland |  |
| | friesland |  |
| | gelderland |  |
| | groningen |  |
| | limburg |  |
| | noord-brabant |  |
| | noord-holland |  |
| | overijssel |  |
| | utrecht |  |
| | zeeland |  |
| | zuid-holland |  |
| **nordrhein-westfalen** | | |
| | arnsberg-regbez |  |
| | detmold-regbez |  |
| | duesseldorf-regbez |  |
| | koeln-regbez |  |
| | muenster-regbez |  |
| **poland** | | |
| | dolnoslaskie |  |
| | kujawsko-pomorskie |  |
| | lodzkie |  |
| | lubelskie |  |
| | lubuskie |  |
| | malopolskie |  |
| | mazowieckie |  |
| | opolskie |  |
| | podkarpackie |  |
| | podlaskie |  |
| | pomorskie |  |
| | slaskie |  |
| | swietokrzyskie |  |
| | warminsko-mazurskie |  |
| | wielkopolskie |  |
| | zachodniopomorskie |  |
| **spain** | | |
| | andalucia |  |
| | aragon |  |
| | asturias |  |
| | cantabria |  |
| | castilla-la-mancha |  |
| | castilla-y-leon |  |
| | cataluna |  |
| | ceuta |  |
| | extremadura |  |
| | galicia |  |
| | islas-baleares |  |
| | la-rioja |  |
| | madrid |  |
| | melilla |  |
| | murcia |  |
| | navarra |  |
| | pais-vasco |  |
| | valencia |  |
| **us/california** | | |
| | norcal |  |
| | socal |  |
